==> python-pygithub-1.26.0-1-any.pkg.tar.xz: usr/lib/python3.5/site-packages/github/tests/__main__.py <==
# -*- coding: utf-8 -*-

# ########################## Copyrights and license ############################
#                                                                              #
# Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
# Copyright 2012 Zearin <zearin@gonk.net>                                      #
# Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
#                                                                              #
# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/          #
#                                                                              #
# PyGithub is free software: you can redistribute it and/or modify it under    #
# the terms of the GNU Lesser General Public License as published by the Free  #
# Software Foundation, either version 3 of the License, or (at your option)    #
# any later version.                                                           #
#                                                                              #
# PyGithub is distributed in the hope that it will be useful, but WITHOUT ANY  #
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS    #
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more #
# details.                                                                     #
#                                                                              #
# You should have received a copy of the GNU Lesser General Public License     #
# along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
#                                                                              #
# ##############################################################################

import sys
import unittest

import github.tests.Framework
import github.tests.AllTests


def main(argv):
    if "--record" in argv:
        github.tests.Framework.activateRecordMode()
        argv = [arg for arg in argv if arg != "--record"]

    if "--auth_with_token" in argv:
        github.tests.Framework.activateTokenAuthMode()
        argv = [arg for arg in argv if arg != "--auth_with_token"]

    unittest.main(module=github.tests.AllTests, argv=argv)


if __name__ == "__main__":
    main(sys.argv)

==> python-pygithub-1.43.5-1-any.pkg.tar.xz: usr/lib/python3.7/site-packages/github/tests/__main__.py <==
# -*- coding: utf-8 -*-

############################ Copyrights and license ############################
#                                                                              #
# Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
# Copyright 2012 Zearin <zearin@gonk.net>                                      #
# Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
# Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
# Copyright 2015 Uriel Corfa <uriel@corfa.fr>                                  #
# Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
# Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
#                                                                              #
# This file is part of PyGithub.                                               #
# http://pygithub.readthedocs.io/                                              #
#                                                                              #
# PyGithub is free software: you can redistribute it and/or modify it under    #
# the terms of the GNU Lesser General Public License as published by the Free  #
# Software Foundation, either version 3 of the License, or (at your option)    #
# any later version.                                                           #
#                                                                              #
# PyGithub is distributed in the hope that it will be useful, but WITHOUT ANY  #
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS    #
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more #
# details.                                                                     #
#                                                                              #
# You should have received a copy of the GNU Lesser General Public License     #
# along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
#                                                                              #
################################################################################

import sys
import unittest

import github.tests.Framework
import github.tests.AllTests


def main(argv):
    if "--record" in argv:
        github.tests.Framework.activateRecordMode()
        argv = [arg for arg in argv if arg != "--record"]

    if "--auth_with_token" in argv:
        github.tests.Framework.activateTokenAuthMode()
        argv = [arg for arg in argv if arg != "--auth_with_token"]

    if "--auth_with_jwt" in argv:
        github.tests.Framework.activateJWTAuthMode()
        argv = [arg for arg in argv if arg != "--auth_with_jwt"]

    unittest.main(module=github.tests.AllTests, argv=argv)


if __name__ == "__main__":
    main(sys.argv)
